//==============================================================================
//
//	s1d13c00_registers.h
//
//	This file lists all of the S1D13C00 registers, which are used by the API,
//	applications, and display drivers.
//
//	©SEIKO EPSON CORPORATION 2024. All rights reserved.
//
//	This driver software is distributed as is, without any warranty of any
//	kind, either express or implied as further specified in the GNU Public
//	License. This software may be used and distributed according to the terms
//	of the GNU Public License, version 2. See the file COPYING in the main
//	directory of this archive for more details.
//
//	You should have received a copy of the GNU General Public License along
//	with this program. If not, see <http://www.gnu.org/licenses/>.
//
//==============================================================================




#pragma once




// Asynchronous System Registers
#define REG30E0_SYSCTRL				0x400030E0		// System Control Register
#define REG30E4_SYSINTS				0x400030E4		// System Interrupts Status Register [READONLY]

// Clock Generator (CLG) Registers
#define REG0000_SYSPROT				0x40000000		// System Protection Register
#define REG0042_CLGOSC				0x40000042		// Oscillation Control Register
#define REG0046_CLGOSC1				0x40000046		// OSC1 Control Register
#define REG004C_CLGINTF				0x4000004C		// CLG Interrupt Flag Register
#define REG004E_CLGINTE				0x4000004E		// CLG Interrupt Enable Register
#define REG0050_CLGFOUT				0x40000050		// CLG FOUT Control Register
#define REG0054_CLGOSC1TRM			0x40000054		// OSC1 Internal Oscillator Trimming Register

// Real-Time Clock (RTC) Registers
#define REG00C0_RTCCTLL				0x400000C0		// RTC Control (Low Byte) Register
#define REG00C1_RTCCTLH				0x400000C1		// RTC Control (High Byte) Register
#define REG00C2_RTCALM1				0x400000C2		// RTC Seconds Alarm Register
#define REG00C4_RTCALM2				0x400000C4		// RTC Hour/Minutes Alarm Register
#define REG00C6_RTCSWCTL			0x400000C6		// RTC Stopwatch Control Register
#define REG00C8_RTCSEC				0x400000C8		// RTC Seconds Register
#define REG00CA_RTCHUR				0x400000CA		// RTC Hour/Minute Register
#define REG00CC_RTCMON				0x400000CC		// RTC Month/Day Register
#define REG00CE_RTCYAR				0x400000CE		// RTC Year/Week Register
#define REG00D0_RTCINTF				0x400000D0		// RTC Interrupt Flag Register
#define REG00D2_RTCINTE				0x400000D2		// RTC Interrupt Enable Register

// GPIO Port Registers
#define REG0200_PORTP0DAT			0x40000200		// GPIO Port P0 Data Register
#define REG0202_PORTP0IOEN			0x40000202		// GPIO Port P0 I/O Enable Register
#define REG0204_PORTP0RCTL			0x40000204		// GPIO Port P0 Pull-up/down Control Register
#define REG0206_PORTP0INTF			0x40000206		// GPIO Port P0 Interrupt Flag Register
#define REG0208_PORTP0INTCTL		0x40000208		// GPIO Port P0 Interrupt Control Register
#define REG020A_PORTP0CHATEN		0x4000020A		// GPIO Port P0 Chattering Filter Enable Register
#define REG020C_PORTP0MODSEL		0x4000020C		// GPIO Port P0 Mode Select Register
#define REG020E_PORTP0FNCSEL		0x4000020E		// GPIO Port P0 Function Select Register
#define REG0210_PORTP1DAT			0x40000210		// GPIO Port P1 Data Register
#define REG0212_PORTP1IOEN			0x40000212		// GPIO Port P1 I/O Enable Register
#define REG0214_PORTP1RCTL			0x40000214		// GPIO Port P1 Pull-up/down Control Register
#define REG0216_PORTP1INTF			0x40000216		// GPIO Port P1 Interrupt Flag Register
#define REG0218_PORTP1INTCTL		0x40000218		// GPIO Port P1 Interrupt Control Register
#define REG021A_PORTP1CHATEN		0x4000021A		// GPIO Port P1 Chattering Filter Enable Register
#define REG021C_PORTP1MODSEL		0x4000021C		// GPIO Port P1 Mode Select Register
#define REG021E_PORTP1FNCSEL		0x4000021E		// GPIO Port P1 Function Select Register
#define REG02E0_PORTCLK				0x400002E0		// GPIO Ports Clock Control Register
#define REG02E2_PORTINTFGRP			0x400002E2		// GPIO Ports Interrupt Flag Group Register [READONLY]

// SPI Registers
#define REG03A0_T16_1CLK			0x400003A0		// SPI T16 CH1 Clock Control Register
#define REG03A2_T16_1MOD			0x400003A2		// SPI T16 CH1 Mode Register
#define REG03A4_T16_1CTL			0x400003A4		// SPI T16 CH1 Control Register
#define REG03A6_T16_1TR				0x400003A6		// SPI T16 CH1 Reload Data Register
#define REG03A8_T16_1TC				0x400003A8		// SPI T16 CH1 Counter Data Register
#define REG03AA_T16_1INTF			0x400003AA		// SPI T16 CH1 Interrupt Flag Register
#define REG03AC_T16_1INTE			0x400003AC		// SPI T16 CH1 Interrupt Enable Register
#define REG03B0_SPIMOD				0x400003B0		// SPI Mode Register
#define REG03B2_SPICTL				0x400003B2		// SPI Control Register
#define REG03B4_SPITXD				0x400003B4		// SPI Transmit Data Register
#define REG03B6_SPIRXD				0x400003B6		// SPI Receive Data Register
#define REG03B8_SPIINTF				0x400003B8		// SPI Interrupt Flag Register
#define REG03BA_SPIINTE				0x400003BA		// SPI Interrupt Enable Register
#define REG03BC_SPITBEDMAEN			0x400003BC		// SPI Transmit Buffer Empty DMA Request Enable Register
#define REG03BE_SPIRBFDMAEN			0x400003BE		// SPI Receive Buffer Full DMA Request Enable Register

// I2C Registers
#define REG03C0_I2CCLK				0x400003C0		// I2C Clock Control Register
#define REG03C2_I2CMOD				0x400003C2		// I2C Mode Register
#define REG03C4_I2CBR				0x400003C4		// I2C Baud-Rate Register
#define REG03C8_I2COADR				0x400003C8		// I2C Own Address Register
#define REG03CA_I2CCTL				0x400003CA		// I2C Control Register
#define REG03CC_I2CTXD				0x400003CC		// I2C Transmit Data Register
#define REG03CE_I2CRXD				0x400003CE		// I2C Receive Data Register
#define REG03D0_I2CINTF				0x400003D0		// I2C Status and Interrupt Flag Register
#define REG03D2_I2CINTE				0x400003D2		// I2C Interrupt Enable Register
#define REG03D4_I2CTBEDMAEN			0x400003D4		// I2C Transmit Buffer Empty DMA Request Enable Register
#define REG03D6_I2CRBFDMAEN			0x400003D6		// I2C Receive Buffer Full DMA Request Enable Register

// QSPI Registers
#define REG0680_T16_2CLK			0x40000680		// QSPI T16 CH2 Clock Control Register
#define REG0682_T16_2MOD			0x40000682		// QSPI T16 CH2 Mode Register
#define REG0684_T16_2CTL			0x40000684		// QSPI T16 CH2 Control Register
#define REG0686_T16_2TR				0x40000686		// QSPI T16 CH2 Reload Data Register
#define REG0688_T16_2TC				0x40000688		// QSPI T16 CH2 Counter Data Register
#define REG068A_T16_2INTF			0x4000068A		// QSPI T16 CH2 Interrupt Flag Register
#define REG068C_T16_2INTE			0x4000068C		// QSPI T16 CH2 Interrupt Enable Register
#define REG0690_QSPIMOD				0x40000690		// QSPI QSPI Mode Register
#define REG0692_QSPICTL				0x40000692		// QSPI Control Register
#define REG0694_QSPITXD				0x40000694		// QSPI Transmit Data Register
#define REG0696_QSPIRXD				0x40000696		// QSPI Receive Data Register
#define REG0698_QSPIINTF			0x40000698		// QSPI Interrupt Flag Register
#define REG069A_QSPIINTE			0x4000069A		// QSPI Interrupt Enable Register
#define REG069C_QSPITBEDMAEN		0x4000069C		// QSPI Transmit Buffer Empty DMA Request Enable Register
#define REG069E_QSPIRBFDMAEN		0x4000069E		// QSPI Receive Buffer Full DMA Request Enable Register
#define REG06A0_QSPIFRLDMAEN		0x400006A0		// QSPI FIFO Data Ready DMA Request Enable Register
#define REG06A2_QSPIMMACFG1			0x400006A2		// QSPI Memory Mapped Access Configuration 1 Register
#define REG06A4_QSPIRMADRH			0x400006A4		// QSPI Remapping Address High Bits Register
#define REG06A6_QSPIMMACFG2			0x400006A6		// QSPI Memory Mapped Access Configuration 2 Register
#define REG06A8_QSPIMB				0x400006A8		// QSPI Mode Byte Register

// SND Registers
#define REG0700_SNDCLK				0x40000700		// SND Clock Control Register
#define REG0702_SNDSEL				0x40000702		// SND Select Register
#define REG0704_SNDCTL				0x40000704		// SND Control Register
#define REG0706_SNDDAT				0x40000706		// SND Data Register
#define REG0708_SNDINTF				0x40000708		// SND Interrupt Flag Register
#define REG070A_SNDINTE				0x4000070A		// SND Interrupt Enable Register
#define REG070C_SNDEMDMAEN			0x4000070C		// SND Buffer Empty DMA Request Enable Register

// REMC Registers
#define REG0720_REMCCLK				0x40000720		// REMC Clock Control Register
#define REG0722_REMCDBCTL			0x40000722		// REMC Data Bit Counter Control Register
#define REG0724_REMCDBCNT			0x40000724		// REMC Data Bit Counter Register
#define REG0726_REMCAPLEN			0x40000726		// REMC Data Active Pulse Length Register
#define REG0728_REMCDBLEN			0x40000728		// REMC Data Bit Length Register
#define REG072A_REMCINTF			0x4000072A		// REMC Status and Interrupt Flag Register
#define REG072C_REMCINTE			0x4000072C		// REMC Interrupt Enable Register
#define REG0730_REMCCARR			0x40000730		// REMC Carrier Waveform Register
#define REG0732_REMCCTL				0x40000732		// REMC Carrier Modulation Control Register

// DMA Controller (DMAC) Registers
#define REG1000_DMACSTAT			0x40001000		// DMAC Status Register
#define REG1004_DMACCFG				0x40001004		// DMAC Configuration Register
#define REG1008_DMACCPTR			0x40001008		// DMAC Control Data Base Pointer Register
#define REG100C_DMACACPTR			0x4000100C		// DMAC Alternate Control Data Base Pointer Register
#define REG1014_DMACSWREQ			0x40001014		// DMAC Software Request Register
#define REG1020_DMACRMSET			0x40001020		// DMAC Request Mask Set Register
#define REG1024_DMACRMCLR			0x40001024		// DMAC Request Mask Clear Register
#define REG1028_DMACENSET			0x40001028		// DMAC Enable Set Register
#define REG102C_DMACENCLR			0x4000102C		// DMAC Enable Clear Register
#define REG1030_DMACPASET			0x40001030		// DMAC Primary-Alternate Set Register
#define REG1034_DMACPACLR			0x40001034		// DMAC Primary-Alternate Clear Register
#define REG1038_DMACPRSET			0x40001038		// DMAC Priority Set Register
#define REG103C_DMACPRCLR			0x4000103C		// DMAC Priority Clear Register
#define REG104C_DMACERRIF			0x4000104C		// DMAC Error Interrupt Flag Register
#define REG2000_DMACENDIF			0x40002000		// DMAC Transfer Completion Interrupt Flag Register
#define REG2008_DMACENDIESET		0x40002008		// DMAC Transfer Completion Interrupt Enable Set Register
#define REG200C_DMACENDIECLR		0x4000200C		// DMAC Transfer Completion Interrupt Enable Clear Register [WRITE ONLY]
#define REG2010_DMACERRIESET		0x40002010		// DMAC Error Interrupt Enable Set Register
#define REG2014_DMACERRIECLR		0x40002014		// DMAC Error Interrupt Enable Clear Register

// Memory Display Controller (MDC) Registers
#define REG3000_MDCDISPCTL			0x40003000		// MDC Display Control Register
#define REG3002_MDCDISPWIDTH		0x40003002		// MDC Display Width Register
#define REG3004_MDCDISPHEIGHT		0x40003004		// MDC Display Height Register
#define REG3006_MDCDISPVCOMDIV		0x40003006		// MDC VCOM Clock Divider Register
#define REG3008_MDCDISPCLKDIV		0x40003008		// MDC Display Clock Divider Register
#define REG300A_MDCDISPPRM21		0x4000300A		// MDC Display Parameters 1 and 2 Register
#define REG300C_MDCDISPPRM43		0x4000300C		// MDC Display Parameters 3 and 4 Register
#define REG300E_MDCDISPPRM65		0x4000300E		// MDC Display Parameters 5 and 6 Register
#define REG3010_MDCDISPPRM87		0x40003010		// MDC Display Parameters 7 and 8 Register
#define REG3012_MDCDISPSTARTY		0x40003012		// MDC Display Update Start Line Register
#define REG3014_MDCDISPENDY			0x40003014		// MDC Display Update End Line Register
#define REG3016_MDCDISPSTRIDE		0x40003016		// MDC Display Frame Buffer Stride Register
#define REG3018_MDCDISPFRMBUFF0		0x40003018		// MDC Display Frame Buffer Base Address 0 Register
#define REG301A_MDCDISPFRMBUFF1		0x4000301A		// MDC Display Frame Buffer Base Address 1 Register
#define REG301C_MDCTRIGCTL			0x4000301C		// MDC Trigger Control Register
#define REG301E_MDCINTCTL			0x4000301E		// MDC Interrupt Control Register
#define REG3020_MDCGFXCTL			0x40003020		// MDC Graphics Control Register
#define REG3022_MDCGFXIXCENTER		0x40003022		// MDC Input X Coordinate Register
#define REG3024_MDCGFXIYCENTER		0x40003024		// MDC Input Y Coordinate Register
#define REG3026_MDCGFXIWIDTH		0x40003026		// MDC Input Width Register
#define REG3028_MDCGFXIHEIGHT		0x40003028		// MDC Input Height Register
#define REG302A_MDCGFXOXCENTER		0x4000302A		// MDC Output X Coordinate Register
#define REG302C_MDCGFXOYCENTER		0x4000302C		// MDC Output Y Coordinate Register
#define REG302E_MDCGFXOWIDTH		0x4000302E		// MDC Output Width Register
#define REG3030_MDCGFXOHEIGHT		0x40003030		// MDC Output Height Register
#define REG3032_MDCGFXXLSCALE		0x40003032		// MDC X Left Scale Register
#define REG3034_MDCGFXXRSCALE		0x40003034		// MDC X Right Scale Register
#define REG3036_MDCGFXYTSCALE		0x40003036		// MDC Y Top Scale Register
#define REG3038_MDCGFXYBSCALE		0x40003038		// MDC Y Bottom Scale Register
#define REG303A_MDCGFXSHEAR			0x4000303A		// MDC X/Y Shear Register
#define REG303C_MDCGFXROTVAL		0x4000303C		// MDC Rotation Register
#define REG303E_MDCGFXCOLOR			0x4000303E		// MDC Color Register
#define REG3040_MDCGFXIBADDR0		0x40003040		// MDC Source Window Base Address 0 Register
#define REG3042_MDCGFXIBADDR1		0x40003042		// MDC Source Window Base Address 1 Register
#define REG3044_MDCGFXOBADDR0		0x40003044		// MDC Destination Window Base Address 0 Register
#define REG3046_MDCGFXOBADDR1		0x40003046		// MDC Destination Window Base Address 1 Register
#define REG3048_MDCGFXISTRIDE		0x40003048		// MDC Source Image Stride Register
#define REG304A_MDCGFXOSTRIDE		0x4000304A		// MDC Destination Image Stride Register
#define REG304C_MDCGFXOWLEFT		0x4000304C		// MDC Output Window Left Edge Register
#define REG304E_MDCGFXOWRIGHT		0x4000304E		// MDC Output Window Right Edge Register
#define REG3050_MDCGFXOWTOP			0x40003050		// MDC Output Window Top Edge Register
#define REG3052_MDCGFXOWBOT			0x40003052		// MDC Output Window Bottom Edge Register
#define REG3054_MDCDISPPRM109		0x40003054		// MDC Display Parameters 9 and 10 Register
#define REG3056_MDCDISPPRM1211		0x40003056		// MDC Display Parameters 11 and 12 Register
#define REG3058_MDCDISPPRM1413		0x40003058		// MDC Display Parameters 13 and 14 Register
#define REG305A_MDCDISPCTL2			0x4000305A		// MDC Display Control 2 Register
#define REG305C_MDCVCNTCOMP			0x4000305C		// MDC VCK Count Compare Register
#define REG305E_MDCVCNT				0x4000305E		// MDC VCK Count Register
#define REG3060_MDCSCRATCHA0		0x40003060		// MDC Scratchpad A0 Register
#define REG3062_MDCSCRATCHA1		0x40003062		// MDC Scratchpad A1 Register
#define REG3064_MDCEPBASEADDR0		0x40003064		// MDC Event Processor Base Address 0 Register
#define REG3066_MDCEPBASEADDR1		0x40003066		// MDC Event Processor Base Address 1 Register
#define REG3068_MDCVCOMCLKCTL		0x40003068		// MDC VCOM Clock Control Register
#define REG306A_MDCEPCTL			0x4000306A		// MDC Event Processor Control Register
#define REG306C_PRODCODE			0x4000306C		// Product Code Register [READ ONLY]
#define REG306E_REVCODE				0x4000306E		// Revision Code Register [READ ONLY]
#define REG3080_MDCBSTCLK			0x40003080		// MDC Voltage Booster/Regulator Clock Control Register
#define REG3084_MDCBSTPWR			0x40003084		// MDC Power Output Control Register
#define REG3088_MDCBSTVMD			0x40003088		// MDC Voltage Booster/Regulator VMD Output Control Register

// The following aren't registers, they are flags that require special code handling.
#define REGFLAG_WAIT_MS				0xFFFFFFF0
#define REGFLAG_WAIT_IOSC			0xFFFFFFF1
#define REGFLAG_WAIT_OSC1			0xFFFFFFF2
#define REGFLAG_WAIT_GFX			0xFFFFFFF3
#define REGFLAG_UPDATE_DISPLAY		0xFFFFFFF4



