//==============================================================================
//
//	s1d13c00_settings.h
//
//	Example header with S1D13C00 settings for a LS013B7DD0x panel. These
//	settings must sync up with the values used in the initSeq[] array located
//	in s1d13c00fb.c.
//
//	For further information on the S1D13C00 register settings, refer to the
//	Hardware Functional Specification.
//
//	For documents and utilities, visit vdc.epson.com.
//
//	©SEIKO EPSON CORPORATION 2024. All rights reserved.
//
//	This driver software is distributed as is, without any warranty of any
//	kind, either express or implied as further specified in the GNU Public
//	License. This software may be used and distributed according to the terms
//	of the GNU Public License, version 2. See the file COPYING in the main
//	directory of this archive for more details.
//
//	You should have received a copy of the GNU General Public License along
//	with this program. If not, see <http://www.gnu.org/licenses/>.
//
//==============================================================================




#pragma once



// Actual display characteristics
#define C00_DISPLAY_WIDTH		260
#define C00_DISPLAY_HEIGHT		260
#define C00_DISPLAY_BPP			8
#define C00_DISPLAY_STRIDE		C00_DISPLAY_WIDTH * (C00_DISPLAY_BPP/8)

// Create and manage a 16 BPP virtual buffer for the system, even though C00 only supports 8 BPP (because Linux doesn't like native 8 BPP)
#define C00_DRIVER_BPP			16
#define C00_DRIVER_STRIDE		C00_DISPLAY_WIDTH * (C00_DRIVER_BPP/8)

// Make the 8-bit background color (AARRGGBB) = black (0xC0)
#define C00_DISPLAY_BG_COLOR	0xC0

#define C00_IOSC_FREQ			20000000UL
#define C00_REG_START_ADDR		0x40000000L
#define C00_MEM_START_ADDR		0x20000000L

// Conversion of display driver's 16-bit RGB565 (RRRRRGGGGGGBBBBB) to S1D13C00's 8-bit RGB (AARRGGBB) memory
#define TO_8_BPP(c16)			(u8)( 0xC0 | ((c16)&0xC000)>>10 | ((c16)&0x0600)>>7 | ((c16)&0x0018)>>3 )
#define TO_16_BPP(c8)			( (((u16)(c8))&0x30)<<10 | (((u16)(c8))&0x0C)<<7 | (((u16)(c8))&0x03)<<3 )



