//==============================================================================
//
//	s1d13c00fb_ioctl.h
//
//	This file provides the ioctl defines used to call the Epson S1D13C00
//	frame buffer driver from a user space application.
//
//	©SEIKO EPSON CORPORATION 2024. All rights reserved.
//
//	This driver software is distributed as is, without any warranty of any
//	kind, either express or implied as further specified in the GNU Public
//	License. This software may be used and distributed according to the terms
//	of the GNU Public License, version 2. See the file COPYING in the main
//	directory of this archive for more details.
//
//	You should have received a copy of the GNU General Public License along
//	with this program. If not, see <http://www.gnu.org/licenses/>.
//
//==============================================================================




#pragma once




struct s1d13c00_ioctl_hwc
{
	int   addr;
	int   value;
	int   id;
	void* buffer;
};




// Register read/write operations (16-bit)
#define S1D13C00_REGREAD		0x4500		// [in] addr=reg-index [out] value=reg-value
#define S1D13C00_REGWRITE		0x4501		// [in] addr=reg-index value=reg-value

// Write multiple registers (sequence)
#define S1D13C00_REGWRITESEQ	0x4502		// [in] buffer=32-bit-addr-and-value-pairs value=num-of-pairs

// Memory read/write operations (16-bit RGB565) for the S1D13C00 display memory
#define S1D13C00_MEMREAD		0x4503		// [in] addr=mem-addr [out] value=mem-value
#define S1D13C00_MEMWRITE		0x4504		// [in] addr=mem-addr value=mem-value

// Burst memory read/write operations (16-bit RGB565) for the S1D13C00 display memory
#define S1D13C00_MEMREADBURST	0x4505		// [in] addr=mem-addr value=num-bytes-to-read [out] buffer=bytes-read
#define S1D13C00_MEMWRITEBURST	0x4506		// [in] addr=mem-addr value=num-bytes-to-write buffer=bytes-to-write

// Perform a Virtual Framebuffer Flush (Refresh)
#define S1D13C00_VBUF_REFRESH	0x4507



